@@ -1,10 +1,11 @@
 use std::io::{Read, Write};
-use crate::error::{BinverseResult, RenameSymbol};
+use crate::error::{BinverseResult, BinverseError};
 
 /// The maximum length in bytes of a varint (u64)
 pub const MAX_LEN: usize = 10;
 
 /// Reads an unsigned 64-bit varint number from a Reader
+#[cfg_attr(feature = "inline", inline)]
 pub fn read<R: Read>(r: &mut R) -> BinverseResult<u64> {
     let mut x: u64 = 0;
     let mut s = 0;
@@ -14,7 +15,7 @@ pub fn read<R: Read>(r: &mut R) -> BinverseResult<u64> {
         let b = b[0];
         if b < 0x80 {
             if i == MAX_LEN-1 && b > 1 {
-                return Err(RenameSymbol::VarIntOverflow)
+                return Err(BinverseError::VarIntOverflow)
             }
             return Ok(x | (b as u64) << s)
         }
@@ -22,11 +23,12 @@ pub fn read<R: Read>(r: &mut R) -> BinverseResult<u64> {
         s += 7;
     }
     // varint was too long and can be considered invalid
-    Err(RenameSymbol::VarIntOverflow)
+    Err(BinverseError::VarIntOverflow)
 }
 
 /// Writes an unsigned 64-bit varint number to a Writer
-pub fn write<W: Write>(mut x: u64, w: &mut W) -> Result<(), RenameSymbol> {
+#[cfg_attr(feature = "inline", inline)]
+pub fn write<W: Write>(mut x: u64, w: &mut W) -> Result<(), BinverseError> {
     while x >= 0x80 {
         w.write_all(&[x as u8 | 0x80])?;
         x >>= 7;
